CameraShakeScript = {}
CameraShakeScript.shakeIntensity = 0.05 -- Intensity of the camera shake
CameraShakeScript.shakeDuration = 0.1 -- Duration of the shake
CameraShakeScript.isShaking = false

function CameraShakeScript:loadMap(name)
    if self.isClient then
        self.player = g_currentMission.player
        addModEventListener(self)
    end
end

function CameraShakeScript:deleteMap()
    removeModEventListener(self)
end

function CameraShakeScript:update(dt)
    if self.isClient then
        if self:isPlayerOnGrass() and self.player.isWalking then
            self:applyCameraShake(dt)
        end
    end
end

function CameraShakeScript:isPlayerOnGrass()
    -- Check if the player is on grass
    local x, y, z = getWorldTranslation(self.player.rootNode)
    local terrainType = getTerrainTypeAtWorldPos(g_currentMission.terrainRootNode, x, 0, z)
    return terrainType == TerrainType.GRASS -- Check if the terrain is grass
end

function CameraShakeScript:applyCameraShake(dt)
    if not self.isShaking then
        self.isShaking = true
        local originalPosition = getWorldTranslation(g_currentMission.camera.rootNode)

        -- Simulate camera shake
        for i = 1, 10 do
            local offsetX = (math.random() - 0.5) * self.shakeIntensity
            local offsetY = (math.random() - 0.5) * self.shakeIntensity
            local offsetZ = (math.random() - 0.5) * self.shakeIntensity
            setWorldTranslation(g_currentMission.camera.rootNode, originalPosition[1] + offsetX, originalPosition[2] + offsetY, originalPosition[3] + offsetZ)

            -- Short pause between shakes
            sleep(self.shakeDuration * 1000)
        end

        -- Reset camera to original position
        setWorldTranslation(g_currentMission.camera.rootNode, originalPosition)
        self.isShaking = false
    end
end

addModEventListener(CameraShakeScript)
